@@ -29,25 +29,14 @@ routes_dict = {
             "version_prefix": "/api/v",
             "endpoints": {
                 "/ticket": {
-                    "version": 1,
-                    "handler": some_handler,
-                    "protector": some_protect,
-                    "get": {},
-                    "post": {
+                    "v14": {
                         "handler": some_handler,
                         "protector": some_protect,
-                    }
-                },
-                "/ticketsssswss": {
-                    "version": 2,
-                    "handler": some_handler,
-                    "protector": some_protect,
-                    "get": {},
-                    "post": {
-                        "handler": some_handler,
-                        "protector": some_protect,
-                        "in_dto": SomeDto,
-                        "out_dto": SomeDto2,
+                        "get": {},
+                        "post": {
+                            "handler": some_handler,
+                            "protector": some_protect,
+                        }
                     }
                 }
             }
