@@ -1,4 +1,5 @@
 from __future__ import annotations
+from dataclasses import dataclass, field
 
 import asyncio
 from asyncio import Task
@@ -11,7 +12,9 @@ from web_foundation.kernel import GenericIMessage
 from web_foundation.workers.io.http.chaining import InputContext
 
 
+@dataclass
 class RtMessage:
+    event_id: str | None = field(default=None)
 
     def _prepare(self, *args, **kwargs) -> str | bytes:
         raise NotImplementedError
@@ -43,16 +46,16 @@ class RtConnection(Generic[GenericIMessage]):
     input_ctx: InputContext
     _last_event_id: int
     _ping_task: Task
-    _ping_enable: bool
+    ping_enable: bool
     _on_disconnect: Callable[[], Coroutine]
 
-    def __init__(self, input_ctx: InputContext, writeable: WriteableObj, debug: bool = True, ping_enable: bool = True,
+    def __init__(self, input_ctx: InputContext, writeable: WriteableObj, debug: bool = False, ping_enable: bool = False,
                  ping_timeout=None,
                  listen_timeout=None):
         self.writeable = writeable
         self.input_ctx = input_ctx
         self.debug = debug
-        self._ping_enable = ping_enable
+        self.ping_enable = ping_enable
         self.ping_timeout = ping_timeout if ping_timeout else 5
         self.listen_timeout = listen_timeout if listen_timeout else 0.1
         self._last_event_id = 0
@@ -62,9 +65,10 @@ class RtConnection(Generic[GenericIMessage]):
 
     async def _ping(self):
         while True:
-            await self.writeable.write(self._ping_msg())
-            if self.debug:
-                logger.debug(f"Sent ping to {self.input_ctx.request.ip}")
+            if self.ping_enable:
+                await self.writeable.write(self._ping_msg())
+                if self.debug:
+                    logger.debug(f"Sent ping to {self.input_ctx.request.ip}")
             await asyncio.sleep(self.ping_timeout)
 
     async def freeze_request(self, on_disconnect: Callable[[], Coroutine]):
@@ -74,13 +78,14 @@ class RtConnection(Generic[GenericIMessage]):
     async def send_after_call(self, event: GenericIMessage, resolve_callback: RtEventCallback):
         msg = await resolve_callback(self, event)
         if msg:
+            self._last_event_id += 1
+            msg.event_id = self._last_event_id
             await self.writeable.write(msg.to_sent)
 
     async def __aenter__(self):
         pass
 
     async def __aexit__(self, exc_type, exc_val, exc_tb):
-        loguru.logger.warning("as[gjasbngkasngjansg")
         await self._on_disconnect()
         if self.debug:
             logger.debug(
@@ -94,13 +99,17 @@ class RtConnection(Generic[GenericIMessage]):
                                 ping_enable: bool = True,
                                 ping_timeout=None,
                                 listen_timeout=None,
-                                debug: bool = True) -> RtConnection:
+                                debug: bool = False) -> RtConnection:
         raise NotImplementedError
 
     @classmethod
     async def _construct_writable(cls, input_ctx: InputContext, *args, **kwargs) -> WriteableObj:
         raise NotImplementedError
 
+    @property
+    def last_event_num(self):
+        return self._last_event_id
+
 
 RtEventCallback = Callable[[RtConnection, GenericIMessage], Coroutine[Any, Any, RtMessage | None]]
 
